@@ -9,9 +9,9 @@ function(object, dir, prg, data)
   m[is.na(m)] <- 2L
   object$p.order <- m
   object$p.order[1L] <- object$p.order[1L] + 1L
-  if(class(object) == "psplinerw1.smooth.spec")
+  if(inherits(object, "psplinerw1.smooth.spec"))
     object$p.order[2L] <- 1L
-  if(class(object) == "psplinerw2.smooth.spec")
+  if(inherits(object, "psplinerw2.smooth.spec"))
     object$p.order[2L] <- 2L
   if(object$bs.dim < 0L)
     object$bs.dim <- 10L
