@@ -1,5 +1,5 @@
 interp2 <- function(x, y, z, xo = NULL, yo = NULL, grid = 30,
-  type = c("akima", "mba", "mgcv", "gam"), linear = FALSE, extrap = FALSE, k = 40)
+  type = c("interp", "mba", "mgcv", "gam"), linear = FALSE, extrap = FALSE, k = 40)
 {
   type <- tolower(type)
   type <- match.arg(type)
@@ -38,22 +38,12 @@ interp2 <- function(x, y, z, xo = NULL, yo = NULL, grid = 30,
   if(type == "mba") {
     fit <- MBA::mba.surf(data.frame("x" = x, "y" = y, "z" = z), grid, grid)$xyz.est$z
   }
-  if(type == "akima") {
-    if(!isTRUE(getOption("use.akima"))) {
-      if(requireNamespace("akima")) {
-        cat("NOTE: Package 'akima' has an ACM license that restricts applications to non-commercial usage.\n")
-      } else {
-        stop(paste("plot3d() can only be used if the 'akima' package is installed. ",
-          "Note that 'akima' has an ACM license that restricts applications to ",
-          "non-commercial usage.", sep = ""))
-      }
-    }
-
-    fit <- try(akima::interp(x, y, z, xo = xo, yo = yo, 
+  if(type == "interp") {
+    fit <- try(interp::interp(x, y, z, xo = xo, yo = yo, 
       duplicate = "mean", linear = linear, extrap = extrap)$z, silent = TRUE)
     if(inherits(fit, "try-error") | all(is.na(fit))) {
-      cat("NOTE: akima::interp() is designed for irregular data points, the coordinates will be slightly jittered to obtain irregular spaced points.\n")
-      fit <- try(akima::interp(jitter(x, amount = .Machine$double.eps),
+      cat("NOTE: interp::interp() is designed for irregular data points, the coordinates will be slightly jittered to obtain irregular spaced points.\n")
+      fit <- try(interp::interp(jitter(x, amount = .Machine$double.eps),
         jitter(y, amount = .Machine$double.eps), z, xo = xo, yo = yo, 
         duplicate = "mean", linear = linear, extrap = extrap)$z, silent = TRUE)
     }
